==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Снимање видеа је у току. Затворити прозор?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Отвори фасциклу</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Слика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Замени камере</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отвори фасциклу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Немате дозволу да управљате овом фасциклом</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Неважећа фасцикла</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отвори фасциклу</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основно</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Локација датотеке</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Снимање</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Рафални режим</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Одлагање снимања</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Испис</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Излазни формат</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 сли</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 сли</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Камера је алат за снимање видеа и слика помоћу камаре рачунара или мрежне камере.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Датотека није сачувана</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Сачувај у:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Слика:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Видео:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Подешавање резолуције</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Резолуција:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Слике:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Видео:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Звучни ефекти</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Режим у огледалу</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Блиц</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Ретка</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 линије</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 линије</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Максимална резолуција:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Заустави снимање</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Заустави усликавање</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Приручни изборник</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Усликај</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Сними видео</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Заустави усликавање</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Нормално</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Живо</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Топло</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Хладно</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Ретро</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Филм</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сива</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Бео-сива</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Лампа</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Укљ.</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Иск.</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Одложи снимање</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Филтри</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Експозиција</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Није пронађена мрежна камера</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Мрежна камера је заузета</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Заустави снимање</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.35.tar.xz: BUILD/src/translations/deepin-camera_sr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Снимање видеа је у току. Затворити прозор?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Отвори фасциклу</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Слика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Замени камере</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отвори фасциклу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Немате дозволу да управљате овом фасциклом</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Неважећа фасцикла</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отвори фасциклу</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основно</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Локација датотеке</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Снимање</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Рафални режим</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Одлагање снимања</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Испис</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Излазни формат</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 сли</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 сли</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Камера је алат за снимање видеа и слика помоћу камаре рачунара или мрежне камере.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Датотека није сачувана</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Сачувај у:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Слика:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Видео:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Подешавање резолуције</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Резолуција:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Слике:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Видео:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Звучни ефекти</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Режим у огледалу</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Блиц</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Мрежа линија</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 линије</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 линије</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Максимална резолуција:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Заустави снимање</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Заустави усликавање</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Приручни изборник</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Усликај</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Сними видео</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Заустави усликавање</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>вебм</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Нормално</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Живо</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Топло</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Хладно</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Ретро</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Филм</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сива</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Бео-сиво</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Лампа</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Укљ.</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Иск.</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Одложи снимање</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Филтери</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Експозија</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Није пронађена мрежна камера</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Мрежна камера је заузета</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Заустави снимање</translation>
    </message>
</context>
</TS>
